******************
Assessment modules
******************

.. automodule:: orion.benchmark.assessment
   :members:

.. toctree::
   :maxdepth: 2
   :caption: Assessment modules of Oríon

   assessment/base
   assessment/averagerank
   assessment/averageresult
